Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(626)

Unified Diff: tests/lib/mirrors/toplevel_members_test.dart

Issue 111643012: Partially implement LibraryMirror.topLevelMembers. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tests/lib/mirrors/synthetic_accessor_properties_test.dart ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tests/lib/mirrors/toplevel_members_test.dart
diff --git a/tests/lib/mirrors/toplevel_members_test.dart b/tests/lib/mirrors/toplevel_members_test.dart
index 1fe613b0cd674c44143a02a6d3d1c210fee4e50c..84839d86670c7c56c17d71b3adfd6fe13b0556db 100644
--- a/tests/lib/mirrors/toplevel_members_test.dart
+++ b/tests/lib/mirrors/toplevel_members_test.dart
@@ -29,13 +29,14 @@ main() {
MirrorSystem.getSymbol('_libraryGetter', lm),
MirrorSystem.getSymbol('_librarySetter=', lm),
MirrorSystem.getSymbol('_libraryMethod', lm),
- #Predicate,
- #Superclass,
- #Interface,
- #Mixin,
- #Class,
- MirrorSystem.getSymbol('_PrivateClass', lm),
- #ConcreteClass],
+ #Predicate, /// 01: ok
+ #Superclass, /// 01: continued
+ #Interface, /// 01: continued
+ #Mixin, /// 01: continued
+ #Class, /// 01: continued
+ MirrorSystem.getSymbol('_PrivateClass', lm), /// 01: continued
+ #ConcreteClass /// 01: continued
+ ],
selectKeys(lm.topLevelMembers, (dm) => true));
Expect.setEquals(
@@ -43,12 +44,13 @@ main() {
const Symbol('libraryVariable='),
MirrorSystem.getSymbol('_libraryVariable', lm),
MirrorSystem.getSymbol('_libraryVariable=', lm),
- #Predicate,
- #Superclass,
- #Interface,
- #Mixin,
- #Class,
- MirrorSystem.getSymbol('_PrivateClass', lm),
- #ConcreteClass],
+ #Predicate, /// 01: continued
+ #Superclass, /// 01: continued
+ #Interface, /// 01: continued
+ #Mixin, /// 01: continued
+ #Class, /// 01: continued
+ MirrorSystem.getSymbol('_PrivateClass', lm), /// 01: continued
+ #ConcreteClass /// 01: continued
+ ],
selectKeys(lm.topLevelMembers, (dm) => dm.isSynthetic));
}
« no previous file with comments | « tests/lib/mirrors/synthetic_accessor_properties_test.dart ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698